C #XCOEFF   V1A   15-FEB-72.
C  LAST UPDATE:
C
      FUNCTION XCOEFF(J1,J2,J3,J4,J5,J6,J7,J8,J9)
C
C *PURPOSE.
C	TO EVALUATE THE "X" OR "9-J" RECOUPLING COEFFICIENT
C AS DEFINED IN ANY STANDARD TEXT ON ANGULAR MOMENTUM.
C
C *PARAMETERS:
C
C  J1  - INTEGER FIRST ANGULAR MOMENTUM QU-NR.
C  J2  - SECOND
C  J3  - THIRD
C  J4  - FOURTH
C  J5  - FIFTH
C  J6  - SIXTH
C  J7  - SEVENTH
C  J8  - EIGHTH
C  J9  - NINTH.
C
C NOTE!!  BY CONVENTION ALL ANGULAR MOMENTUM QUANTUM NUMBERS ARE
C INTEGERS WITH TWICE THEIR PHYSICAL VALUE.  THIS APPLIES TO
C ALL THE PARAMETERS ABOVE.  WHEN WRITTEN AS A 9-J SYMBOL
C THE ORDERING OF THE J'S IS EITHER:
C
C	J1  J2  J3		J1  J4  J7
C	J4  J5  J6		J2  J5  J8
C	J7  J8  J9		J3  J6  J9
C
C THESE GIVING IDENTICAL VALUES.
C
C INPUT PARAMETERS:
C	J1, J2, J3, J4, J5, J6, J7, J8, J9
C OUTPUT PARAMETERS:
C	(ONLY THE REAL FUNCTION VALUE)
C
C *METHOD.
C	THE STANDARD FORMULA DEFINING THE X-COEFFICIENT IN TERMS
C OF A SUM OF PRODUCTS OF RACAH COEFFICIENTS IS USED.  NOTE THAT
C THIS VERSION HAS NO TEST FOR THE MANY SIMPLE CASES OF X-COEFF
C WHICH CAN BE EVALUATED MORE QUICKLY.
C
C *ACCURACY.
C
C *RESTRICTIONS.
C
C *ERROR CONDITIONS.
C	THE VALUE ZERO WILL BE RETURNED FOR NON PHYSICAL COMBINATIONS
C OF QUANTUM NUMBERS.
C
C *NON STANDARD ROUTINES CALLED.
C	RACAH - RACAH OR 6-J COEFFICIENT - MRMLIB.
C
C *TYPICAL TIMES.
C
C *ORIGIN.   M.R.MANNING.
C
C *COMMENTS.
C
C #END.
C
      IND=MIN0(J1+J9,J8+J4,J2+J6)
      IST=MAX0(IABS(J1-J9),IABS(J4-J8),IABS(J2-J6) )
      XCOEFF=0.
      DO 10 I=IST,IND,2
10    XCOEFF= XCOEFF + FLOAT(I+1)*RACAH(J1,J9,J2,J6,I,J3)*
     1    RACAH(J2,J6,J8,J4,I,J5)*RACAH(J8,J4,J9,J1,I,J7)
C
      RETURN
      END
����������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������